#
# spec file for package apfel
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define soname libAPFEL0_0_0
# Need -ffat-lto-objects for the static lib
%define _lto_cflags -flto=auto -ffat-lto-objects
Name:           apfel
Version:        3.1.1
Release:        2.2
Summary:        A Probability Distribution Function Evolution Library
License:        GPL-3.0-or-later
Group:          Development/Libraries/C and C++
URL:            http://apfel.hepforge.org/
Source:         https://github.com/scarrazza/%{name}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM apfel-dont-set-default-reltype.patch badshah400@gmail.com -- Don't assume 'RELEASE' as the release type, this should be set by user
Patch1:         apfel-dont-set-default-reltype.patch
BuildRequires:  %{python_module LHAPDF}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module wheel}
BuildRequires:  LHAPDF-devel
BuildRequires:  cmake >= 3.15
BuildRequires:  gcc-c++
BuildRequires:  gcc-fortran
BuildRequires:  libboost_headers-devel
BuildRequires:  python-rpm-macros
BuildRequires:  swig
Requires:       python-LHAPDF
Requires(post): update-alternatives
Requires(postun): update-alternatives
%python_subpackages

%description
APFEL is a library to perform the combined QCD+QED DGLAP
evolution of parton distributions.

%package -n %{soname}
Summary:        A Probability Distribution Function Evolution Library
Group:          System/Libraries
# Problem with older naming scheme
Conflicts:      libAPFEL0 <= 3.0.6

%description -n %{soname}
APFEL is a library to perform the combined QCD+QED DGLAP
evolution of parton distributions.

This package provides the shared libraries for %{name}.

%package -n %{name}-devel
Summary:        Development files for Apfel, a PDF Evolution Library
Requires:       %{soname} = %{version}
Requires:       LHAPDF-devel
Recommends:     %{name}-doc = %{version}

%description -n %{name}-devel
APFEL is a library to perform the combined QCD+QED DGLAP
evolution of parton distributions.

This package provides the source files required to develop
applications with %{name}.

%package -n %{name}-devel-static
# We need to build and install the static lib as there is no way to
# disable it during configuration stage and it pollutes the cmake files
Summary:        Static development files for Apfel, a PDF Evolution library

%description -n %{name}-devel-static
APFEL is a library to perform the combined QCD+QED DGLAP
evolution of parton distributions.

This package provides the static library required to develop
applications with %{name}.

%package -n %{name}-doc
Summary:        Documentation for APFEL, a PDF evolution library

%description -n %{name}-doc
This package provides documentation for APFEL in PDF (Portable
Document Format), a PDF (Probability Distribution Function) evolution
library.

%prep
%autosetup -p1

%build
%{python_expand # Necessary to run configure with all $python flavors
export PYTHON=%{_bindir}/$python
mkdir ../$python
cp -pr ./ ../$python
pushd ../$python
%cmake \
  -DCMAKE_RELEASE_TYPE="RelwithDebInfo" \
  -DPython_EXECUTABLE:PATH=${PYTHON} \
  -DAPFEL_DOWNLOAD_PDFS:BOOL=OFF
%cmake_build
popd
}

%install
%{python_expand #  all $python flavors as configured above
export PYTHON=%{_bindir}/$python
pushd ../$python
%cmake_install
%python_clone -a %{buildroot}%{_bindir}/apfel
popd
}

# REMOVE libtool ARCHIVES
find %{buildroot} -type f -name "*.la" -delete -print

# FIX env BASED SCRIPT INTERPRETER
sed -Ei "1{s|#\!\s*%{_bindir}/env bash|#\!/bin/bash|}" %{buildroot}%{_bindir}/apfel-config

# REMOVE INSTALLED README, INSTALL IT USING %%doc INSTEAD
rm -fr %{buildroot}%{_docdir}/%{name}/README
rm -fr %{buildroot}%{_datadir}/doc/apfel/README
rm -fr %{buildroot}%{_datadir}/apfel/README

%post   -n %{soname} -p /sbin/ldconfig
%postun -n %{soname} -p /sbin/ldconfig

%post
%python_install_alternative apfel

%postun
%python_uninstall_alternative apfel

%files -n %{soname}
%{_libdir}/*.so.*

%files -n %{name}-devel
%license COPYING
%doc AUTHORS ChangeLog NEWS README
%{_bindir}/%{name}-config
%{_includedir}/APFEL/
%{_libdir}/*.so

%files -n %{name}-devel-static
%license COPYING
%{_libdir}/*.a
%{_datadir}/APFEL/

%files %{python_files}
%python_alternative %{_bindir}/apfel
%{python_sitearch}/apfel/
%{python_sitearch}/apfel-%{version}-py%{python_version}.egg-info

%files -n %{name}-doc
%doc doc/pdfs/manual.pdf

%changelog
* Fri Feb 23 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Remove README in one possible location where cmake
  would potentially install it to.
* Thu Dec 28 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.1.1:
  * CMakeLists.txt: define APFEL_VERSION, like in config.h.in
    (gh#scarazza/apfel#53).
- Drop apfel-fix-project-version.patch: incorporated upstream.
- Rebase apfel-dont-set-default-reltype.patch for update.
* Wed Nov 22 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.1.0:
  * F2C_CCE and F2C_CCP (gh#scarazza/apfel#41).
  * Make the --disable-pywrap option work (gh#scarazza/apfel#43).
  * Some changes to cmake build system to simplify the flags
    treatment and the python installation (gh#scarazza/apfel#42).
  * Actually functioning cmake (gh#scarazza/apfel#44).
  * cmake fixes and CI with cmake (gh#scarazza/apfel#46).
  * Update README (gh#scarazza/apfel#47).
  * Remove Circle CI (gh#scarazza/apfel#48).
  * Drop CircleCI badge (gh#scarazza/apfel#51).
  * Remove autotool builds (gh#scarazza/apfel#49).
  * Update README removing autotools instructions
    (gh#scarazza/apfel#52).
- Add apfel-fix-project-version.patch -- Use the correct version
  in defining project in CMakeLists.txt
- Add apfel-dont-set-default-reltype.patch -- Don't assume
  'RELEASE' as the release type, this should be set at the cmake
  command line.
- Build static lib and install it as part of a -devel-static
  package; upstream cmake does not allow disabling static libs and
  it ends up everywhere in the cmake files, so cannot just ignore
  it either.
- Use cmake for build in keeping with upstream; BuildRequires:
  cmake >= 3.15.
- Add BuildRequires: swig needed to generate python wrappings.
* Thu Jan 20 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.0.6:
  * Merging vbertone fork.
- Drop apfel-allow-disabling-pywrap.patch: With py3 supported,
  this is no longer required.
- Enable python bindings: apfel now python3 compliant.
- Enable multiple python flavours; Requires(post) and
  Requires(postun) for update-alternatives.
* Tue Jun  8 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.0.5:
  + No release notes.
- Rename source tarball to %%{name}-%%{version} format.
* Tue Apr 28 2020 Atri Bhattacharya <badshah400@gmail.com>
- Add apfel-allow-disabling-pywrap.patch to support building
  without building the python extensions and binaries; build
  python bindings and python-based binaries only for distributions
  supporting python2 since apfel does not support python3.
- Add libtool BuildRequires and run autoreconf since patch touches
  build files.
* Tue Jun 25 2019 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.0.4:
  + New release for use with the latest version of HELL (no more
    changes documented by upstream).
* Sun Jan 13 2019 Jan Engelhardt <jengelh@inai.de>
- Update descriptions.
* Sat Jan 12 2019 badshah400@gmail.com
- Install pre-generated PDF manual as part of a new -doc package.
- Move ListFunctions binary into -devel package: apfel-config,
  already being installed as part of the devel package, is partly
  broken without this.
- Change `env` based script interpreter in apfel-config to
  directly call /bin/bash instead.
- Use %%%%license macro to install the license file.
- Run spec-cleaner for minor specfile cleanups
* Sat Jul 14 2018 badshah400@gmail.com
- Update to version 3.0.3:
  + Undocumented bug fixes.
* Mon Mar 26 2018 stefan.bruens@rwth-aachen.de
- Drop Qt4 BuildRequires, ApfelGUI has been deprecated in version 2.7
  and removed subsequently
- Build on all archs
* Sat Oct 28 2017 badshah400@gmail.com
- Update to version 3.0.2:
  + Update list-func function.
* Tue Jul 11 2017 badshah400@gmail.com
- Update to version 3.0.1:
  * Fixing bug in the upwards VFNS evolution of alpha.
* Wed Apr  5 2017 badshah400@gmail.com
- Update to version 3.0.0:
  * Implementation of the full NLO QCD+QED correction in the DGLAP
    evolution and in the DIS structure functions.
  * Interfacing APFEL to HELL (v.1.1) for the computation of the
    ZM small-x resummed structure functions.
  * Optimisation of the caching for PDFs and structure functions.
  * Completed external evolution operator when QED corrections are
    enabled.
  * Update of the documentation.
  * Clean up of the code.
  * Minor bug fixes and adjustments.
* Wed Apr  5 2017 badshah400@gmail.com
- Add BuildRequires: libboost_headers-devel or boost-devel as
  appropriate to the openSUSE versions to fix builds.
* Fri Jan 27 2017 bg@suse.com
- enable build on s390x
* Mon Aug  8 2016 badshah400@gmail.com
- Update to version 2.7.2:
  + Full intrinsic charm contributions up to O(as) in both NC and
    CC sectors.
  + Possibility to set the heavy quark thresholds different from
    the heavy quark masses in both the pole and the MSbar schemes.
  + New and more accurate parametrization of the O(as^2) NC
    massive coefficient functions over a wider range in Q^2.
  + Implementation of the cached PDF evolution.
  + Fix of minor bugs and minor improvements.
  + Update of the documentation.
- Upstream now also installs README in /usr/share/apfel; delete
  from both non-standard locations and use %%doc to package it
  instead.
* Mon Feb 15 2016 jengelh@inai.de
- Expand PDF acronym in summaries
- Drop author list from description, openSUSE does not do this
  since many many months.
* Tue Feb  2 2016 badshah400@gmail.com
- Update to version 2.7.0:
  + Implementation of the polarized evolution up to NNLO.
  + Implementation of the LO contribution to intrinsic charm in
    FONLL.
  + Possibility to perform dynamical factorization/renormalization
    scale variations.
  + New functions to feed higher order EW corrections.
  + Reduction of the memory footprint.
  + Speed up of the initialization phase.
  + Minor improvements and bug fixings.
- Changes from version 2.6.0:
  + Implementation of the factorization and renormalization scale
    variation for the DIS structure functions.
  + Implementation of a faster solution for the QCD+QED unified
    solution of the DGLAP equation.
  + Improving the production of the LHAPDF grids.
  + Improving the accuracy of the truncated solution of the DGLAP
    equation (from 3- to 5-point derivative).
  + Colorful banner.
  + Minor improvements.
- Apfelgui is deprecated, drop all supporting files:
  +  apfelgui.changes.
  +  pre_checkin.sh.
  +  apfelgui.spec.
  +  apfelgui.spec.in.
  +  README.
* Thu Jul  9 2015 badshah400@gmail.com
- Update to version 2.5.2:
  + Implementation of truncated PDF evolution.
  + libAPFELevol: a light version of APFEL with just evolution.
  + general code improvements.
  + Fixed bugs:
  - Fixed bug in the computation of the SIA cross-sections.
  - Fixed xmax and xmin tolerance.
- Changes from previous versions 2.3.4 through 2.4.0:
  + See https://github.com/scarrazza/apfel/releases.
* Fri Mar 20 2015 badshah400@gmail.com
- Update to version 2.3.3:
  + Functions for the production of FK tables.
  + Updated format of the output LHAPDF grids.
  + Implementation of semi-inclusive e^+e^- annihilation structure
    functions,
  + Added flag to the apfel-config script to list the APFEL
    functions.
- Changes from previous versions:
  + Long list of changes since previous packaged version, see NEWS
    file.
- Packaging changes: Use LHAPDF 6.x (instead of 5.x) for building,
  since apfel is now LHAPDFv6 compatible.
- Since version 2.3.0, building on 32-bit architectures is
  unsupported by upstream.
* Thu May  1 2014 badshah400@gmail.com
- apfelgui: Requires(post) and Requires(postun) should be on
  desktop-file-utils (for %%desktop_database_post(un) scriptlets)
  rather than on update-desktop-files.
* Tue Apr 29 2014 badshah400@gmail.com
- apfel-devel should have a "Requires:" on lhapdf-devel <= 5.9.1.
* Sat Apr 19 2014 badshah400@gmail.com
- Build and install hicolor icons (introduces a BuildRequires on
  hicolor-icon-theme) and desktop menu entry.
* Sun Apr 13 2014 badshah400@gmail.com
- Initial package (version 2.0.1).
